from typing import Any

import aiohttp

from settings import API_BASE

headers = {"Content-Type": "application/json"}


# TODO: rewrite to orm usage?


async def _request_endpoint(query_name, body) -> Any:
    async with aiohttp.ClientSession() as session:
        async with session.post(API_BASE, headers=headers, json=body) as response:
            print(f"[services.core] {query_name} HTTP Response {response.status} {await response.text()}")
            if response.status == 200:
                r = await response.json()
                if r:
                    return r.get("data", {}).get(query_name, {})
    return []


async def get_followed_shouts(author_id: int):
    query_name = "load_shouts_followed"
    operation = "GetFollowedShouts"

    query = f"""query {operation}($author_id: Int!, limit: Int, offset: Int) {{
        {query_name}(author_id: $author_id, limit: $limit, offset: $offset) {{ id slug title }}
    }}"""

    gql = {
        "query": query,
        "operationName": operation,
        "variables": {"author_id": author_id, "limit": 1000, "offset": 0},  # FIXME: too big limit
    }

    return await _request_endpoint(query_name, gql)


async def get_shout(shout_id):
    query_name = "get_shout"
    operation = "GetShout"

    query = f"""query {operation}($slug: String, $shout_id: Int) {{
        {query_name}(slug: $slug, shout_id: $shout_id) {{ id slug title authors {{ id slug name pic }} }}
    }}"""

    gql = {"query": query, "operationName": operation, "variables": {"slug": None, "shout_id": shout_id}}

    return await _request_endpoint(query_name, gql)
